==> cil_estimator-0.0.3.tar.gz: cil_estimator-0.0.3/README.md <==
# Welcome to cil_estimator

by **Andreas Rupp**.

[![PyPI Version](https://badge.fury.io/py/cil_estimator.svg)](
https://badge.fury.io/py/cil_estimator)
[![PyPI Downloads](https://img.shields.io/pypi/dm/cil_estimator.svg?label=PyPI%20downloads)](
https://pypi.org/project/cil_estimator/)
[![GitHub Repository](https://img.shields.io/badge/Source_code-GitHub-red.svg)](
https://github.com/AndreasRupp/cil_estimator)
[![GitHub Issues](https://img.shields.io/badge/Issue_tracking-GitHub-blue.svg)](
https://github.com/AndreasRupp/cil_estimator/issues)

It contains a Python based framework for parameter estimation, which is currently under
construction.

It may be installed using

    $ pip install git+https://github.com/AndreasRupp/cil_estimator.git

for the latest version, which is located in the GitHub repository. Alternatively, you can use

    $ python3 -m pip install cil_estimator

to obtain the latest stable version from [PyPI](https://pypi.org/).


# Copyright, License, and Contribution Policy

This directory contains the cil_estimator library.

The cil_estimator library is copyrighted by the authors of `cil_estimator`. This term refers to the
people listed at the very top of this page.

This library is free software; you can use it, redistribute it, and/or modify it under the terms
of the <b>GNU Lesser General Public License</b> as published by the Free Software Foundation; either
<b>version 2.1</b> of the License, or (at your option) any later version. The full text of the GNU
Lesser General Public version 2.1 is quoted in [License.txt](
https://github.com/AndreasRupp/cil_estimator/blob/main/License.txt).


## Contributions

As a contributor to this project, you agree that all of your contributions be governed by the
<b>Developer Certificate of Origin version 1.1</b>. This project does not require copyright
assignments for contributions. This means that the copyright for code contributions in this project
is held by its respective contributors who have each agreed to release their contributed code under
a compatible open source license (LGPL v2.1 for library code). The full text of the Developer
Certificate of Origin version 1.1 is quoted in [DeveloperCertificateOfOrigin.txt](
https://github.com/AndreasRupp/cil_estimator/blob/main/DeveloperCertificateOfOrigin.txt).


## Contact

For further questions regarding licensing and commercial use please contact Andreas Rupp directly
using [Email](mailto:info@rupp.ink).


## Links

- The license can be found in [License.txt](
  https://github.com/AndreasRupp/cil_estimator/blob/main/License.txt). It contains the [GNU Lesser
  General Public License version 2.1](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html).
- The developer certificate of origin can be found in [DeveloperCertificateOfOrigin.txt](
  https://github.com/AndreasRupp/cil_estimator/blob/main/DeveloperCertificateOfOrigin.txt). It
  contains the [Developer Certificate of Origin version 1.1](https://developercertificate.org/).

==> cil_estimator-0.1.0.tar.gz: cil_estimator-0.1.0/README.md <==
# `cil_estimator` is now `ecdf_estimator`!

This software package is deprecated! Thus, we do not recommend to use the version of `cil_estimator`
that is provided here. Nonetheless, `cil_estimator` is further developed and can be obtained from
[GitHub](https://github.com/AndreasRupp/ecdf_estimator) and [PyPI](
https://pypi.org/project/ecdf-estimator/) under its new name `ecdf_estimator`.


# Welcome to cil_estimator

[![PyPI Version](https://badge.fury.io/py/cil_estimator.svg)](
https://badge.fury.io/py/cil_estimator)
[![PyPI Downloads](https://img.shields.io/pypi/dm/cil_estimator.svg?label=PyPI%20downloads)](
https://pypi.org/project/cil_estimator/)
[![GitHub Repository](https://img.shields.io/badge/Source_code-GitHub-red.svg)](
https://github.com/AndreasRupp/ecdf_estimator)
[![GitHub Issues](https://img.shields.io/badge/Issue_tracking-GitHub-blue.svg)](
https://github.com/AndreasRupp/ecdf_estimator/issues)

It contains a Python based framework for parameter estimation, which is currently under
construction.

It may be installed using

    $ pip install git+https://github.com/AndreasRupp/ecdf_estimator.git

for the latest version, which is located in the GitHub repository. Alternatively, you can use

    $ python3 -m pip install ecdf_estimator

to obtain the latest stable version from [PyPI](https://pypi.org/).


# Copyright, License, and Contribution Policy

This directory contains the ecdf_estimator library.

The ecdf_estimator library is copyrighted by the authors of `ecdf_estimator`. This term currently
refers to Andreas Rupp.

This library is free software; you can use it, redistribute it, and/or modify it under the terms
of the <b>GNU Lesser General Public License</b> as published by the Free Software Foundation; either
<b>version 2.1</b> of the License, or (at your option) any later version. The full text of the GNU
Lesser General Public version 2.1 is quoted in [License.txt](
https://github.com/AndreasRupp/ecdf_estimator/blob/main/License.txt).


## Contributions

As a contributor to this project, you agree that all of your contributions be governed by the
<b>Developer Certificate of Origin version 1.1</b>. This project does not require copyright
assignments for contributions. This means that the copyright for code contributions in this project
is held by its respective contributors who have each agreed to release their contributed code under
a compatible open source license (LGPL v2.1 for library code). The full text of the Developer
Certificate of Origin version 1.1 is quoted in [DeveloperCertificateOfOrigin.txt](
https://github.com/AndreasRupp/ecdf_estimator/blob/main/DeveloperCertificateOfOrigin.txt).


## Contact

For further questions regarding licensing and commercial use please contact Andreas Rupp directly
using [Email](mailto:info@rupp.ink).


## Links

- The license can be found in [License.txt](
  https://github.com/AndreasRupp/ecdf_estimator/blob/main/License.txt). It contains the [GNU Lesser
  General Public License version 2.1](https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html).
- The developer certificate of origin can be found in [DeveloperCertificateOfOrigin.txt](
  https://github.com/AndreasRupp/ecdf_estimator/blob/main/DeveloperCertificateOfOrigin.txt). It
  contains the [Developer Certificate of Origin version 1.1](https://developercertificate.org/).
